<?php

namespace Drupal\iconset\Asset;

/**
 * An asset which wraps information about an icon font-face.
 *
 * The asset includes data about the font-face (font family, weight, etc) and
 * the characters in the font which resolve to icons in this font-face.
 */
class FontAsset implements FontAssetInterface {

  /**
   * Creates a new instance of FontAsset, to wrap data about an icon font-face.
   *
   * @param array $font
   *   Information about the font-face if available (family, weight, etc..).
   * @param array $icons
   *   An array of icons keyed by ID, and should contain label and unicode data
   *   need to render the icon font.
   */
  public function __construct(
    protected array $font,
    protected array $icons = [],
  ) {}

  /**
   * {@inheritdoc}
   */
  public function getFontInfo(): array {
    return $this->font;
  }

  /**
   * {@inheritdoc}
   */
  public function getIcons(): array {
    return $this->icons;
  }

  /**
   * {@inheritdoc}
   */
  public function getIcon(string $iconId): array|false {
    return $this->icons[$iconId] ?? FALSE;
  }

}
