<?php

namespace Drupal\iconset\Asset;

/**
 * A file asset that wraps and manages a SVG sprite file with multiple icons.
 */
class SvgSpriteAsset implements FileAssetInterface {

  /**
   * Create a new instance of the SvgSpriteAsset class.
   *
   * @param string $filepath
   *   The path of the SVG sprite file.
   * @param array $icons
   *   An array of icon data, which is keyed by the icon ID, and has the label
   *   and viewBox information for each icon managed by this asset.
   */
  public function __construct(
    protected string $filepath,
    protected array $icons,
  ) {}

  /**
   * {@inheritdoc}
   */
  public function getFilepath(): string {
    return $this->filepath;
  }

  /**
   * {@inheritdoc}
   */
  public function getIcons(): array {
    return $this->icons;
  }

  /**
   * {@inheritdoc}
   */
  public function getIcon(string $iconId): array|false {
    return $this->icons[$iconId] ?? FALSE;
  }

}
