<?php

namespace Drupal\iconset\Attribute;

use Drupal\Component\Plugin\Attribute\Plugin;

/**
 * Defines a Plugin attribute for icon handler plugins.
 *
 * @see \Drupal\Component\Plugin\Attribute\Plugin
 * @see \Drupal\iconset\Plugin\IconHandlerInterface
 * @see \Drupal\iconset\Plugin\IconHandlerPluginManager
 * @see plugin_api
 *
 * @ingroup iconset_handler_plugins
 */
#[\Attribute(\Attribute::TARGET_CLASS)]
class IconsetIconHandler extends Plugin {

  /**
   * Create new attribute instance for iconset handler plugins.
   *
   * @param string $id
   *   The Icon plugin ID.
   * @param \Stringable|string $label
   *   The human friendly name of the icon handler plugin.
   * @param \Stringable|string|null $help
   *   Help or description or help text to help understand what this plugin is.
   * @param bool $allow_directory
   *   If a file based icon handler, does it support directories as assets.
   * @param string|null $file_extension
   *   The file extension (including the period), of valid files. This value is
   *   optional, and not use for most of the icon handler plugins. Some icon
   *   handlers which might support different file options might require this
   *   (eg \DirectoryHandler).
   * @param array $libraries
   *   The list Drupal libraries that should be included for JS handling.
   */
  public function __construct(
    public readonly string $id,
    public \Stringable|string $label,
    public \Stringable|string|null $help = NULL,
    public bool $allow_directory = FALSE,
    public ?string $file_extension = NULL,
    public array $libraries = [],
  ) {}

}
